psychopy_ext.exp.OrderedDict
============================

.. currentmodule:: psychopy_ext.exp

.. autoclass:: OrderedDict

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~OrderedDict.__init__
      ~OrderedDict.clear
      ~OrderedDict.copy
      ~OrderedDict.fromkeys
      ~OrderedDict.get
      ~OrderedDict.has_key
      ~OrderedDict.items
      ~OrderedDict.iteritems
      ~OrderedDict.iterkeys
      ~OrderedDict.itervalues
      ~OrderedDict.keys
      ~OrderedDict.pop
      ~OrderedDict.popitem
      ~OrderedDict.setdefault
      ~OrderedDict.update
      ~OrderedDict.values
      ~OrderedDict.viewitems
      ~OrderedDict.viewkeys
      ~OrderedDict.viewvalues
   
   

   
   
   